@@ -1,11 +1,3 @@
-# Copyright (C) 2022-2025 Cochise Ruhulessin
-#
-# All rights reserved. No warranty, explicit or implicit, provided. In
-# no event shall the author(s) be liable for any claim or damages.
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 import os
 import pathlib
 
@@ -23,7 +15,7 @@ class EnvironmentVariables(pydantic.BaseModel):
     )
 
     vardir: pathlib.Path = pydantic.Field(
-        alias='APP_VARDIR',
+        alias='VARDIR',
         default=...
     )
 
@@ -32,8 +24,8 @@ class EnvironmentVariables(pydantic.BaseModel):
         name = params.get('name')
         if not isinstance(name, str):
             raise pydantic.ValidationError()
-        if not params.get('APP_VARDIR'):
-            params['APP_VARDIR'] = f'/var/lib/{name}'
+        if not params.get('VARDIR'):
+            params['VARDIR'] = f'/var/lib/{name}'
         return params
 
     @classmethod
